Module pipeline

Module pipeline 

Functions

compress
Compresses input under policy using the best available estimator (exact tiktoken when the feature is compiled in and its data is reachable, heuristic otherwise).
compress_with_estimator