Functions
- compress
- Compresses
inputunderpolicyusing the best available estimator (exacttiktokenwhen the feature is compiled in and its data is reachable, heuristic otherwise). - compress_
with_ estimator
input under policy using the best available estimator (exact tiktoken
when the feature is compiled in and its data is reachable, heuristic otherwise).